import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * Ventana (JFrame) principal del programa.
 * @author Carlos Cortes
 */
public class Frame extends JFrame
{
    private Panel panel;
    
    private JMenuBar menuBar;
    
    /**
     */
    public Frame()
    {
        setTitle(Defs.FRAME_TITLE);
        setSize(Defs.FRAME_DEFAULT_WIDTH, Defs.FRAME_DEFAULT_HEIGHT);
        
        /* ENSAMBLANDO LA BARRA DE MENU */
        menuBar = new JMenuBar();
        //-------------------------------------------------------
        JMenu     menuCrear       = new JMenu("Crear");
        JMenuItem menuCrearFuente = new JMenuItem("Fuente CC");
        JMenuItem menuCrearResist = new JMenuItem("Resistencia");
        JMenuItem menuCrearTierra = new JMenuItem("Tierra");
        //-------------------------------------------------------
        JMenu     menuEditar      = new JMenu("Editar");
        JMenuItem menuEditarMover = new JMenuItem("Trasladar");
        JMenuItem menuEditarRotar = new JMenuItem("Rotar");
        
        menuBar.add(menuCrear);
        menuCrear.add(menuCrearFuente);
        menuCrear.add(menuCrearResist);
        menuCrear.add(menuCrearTierra);
        
        menuBar.add(menuEditar);
        menuEditar.add(menuEditarMover);
        menuEditar.add(menuEditarRotar);
        
        /* AGREGANDO LAS ACCIONES DEL MENU */
        menuCrearFuente.addActionListener(new MenuHandler(Defs.FUENTECC));
        menuCrearResist.addActionListener(new MenuHandler(Defs.RESISTOR));
        menuCrearTierra.addActionListener(new MenuHandler(Defs.GND));
        menuEditarMover.addActionListener(new MenuHandler(Defs.MOVER));
        menuEditarRotar.addActionListener(new MenuHandler(Defs.ROTAR));
        
        setJMenuBar(menuBar);
        
        /* CREANDO PANEL */
        panel = new Panel();
        Container contentPane = getContentPane();
        contentPane.add(panel);
    }
    
    /**
     * Clase interna a Frame.
     * Realiza las acciones solicitadas via menu.
     */
    private class MenuHandler implements ActionListener
    {
        private String command, input;
        private float valor;

        public MenuHandler(String c)
        {
            command = c;
        }
        
        public void actionPerformed(ActionEvent e)
        {
            /* Acciones del menu Crear */
            if (command.equals(Defs.FUENTECC))
            {
                input = JOptionPane.showInputDialog(panel,
                    Defs.FUENTECC_MESSAGE_PROMPT, Defs.FUENTECC_DEFAULT_VALUE);
                if (input == null) return;
                try
                {
                    valor = Float.parseFloat(input);
                    panel.add(new Componente(Defs.FUENTECC, valor));
                }
                catch (IllegalArgumentException err)
                { return; }
            }
            else
            if (command.equals(Defs.RESISTOR))
            {
                input = JOptionPane.showInputDialog(panel,
                    Defs.RESISTOR_MESSAGE_PROMPT, Defs.RESISTOR_DEFAULT_VALUE);
                if (input == null) return;
                try
                {
                    valor = Float.parseFloat(input);
                    panel.add(new Componente(Defs.RESISTOR, valor));
                }
                catch (IllegalArgumentException err)
                { return; }
            }
            else
            if (command.equals(Defs.GND))
                panel.add(new Componente(Defs.GND, 0));
            else
            /* Acciones del menu Editar */
            if (command.equals(Defs.MOVER))
                panel.setAccion(Defs.MOVER);
            else
            if (command.equals(Defs.ROTAR))
                panel.setAccion(Defs.ROTAR);
        }
    }
}
